;
;
; =============================================================================
;
;   EL32_CE.asm		DEMO9S08SH8 CE Test Program
;                                 
;   Version:		1.0   Created 01/10/07
;   Author:		Spencer Ruggles , Axiom Mfg.
;   Compiler:		CASMHCS08 / WinIDE2
;       
;   Platform:		DEMO9S08EL32, AXM-0398
;   Purpose:		Demonstration Program
; =============================================================================
;
; Demonstration program for DEMO9S08SH8 board. 

; ====================  EQUATES ===============================================

	include '9S08SH8.equ'	; 9S08EL32 Equates

; ====================  LOCAL EQUATES ========================================= 

RAM:	equ $80		; start of RAM
STACK:	equ $280	; top of RAM + 1
FLASH:	equ $E000	; start of FLASH

BDH:	equ $00		; SCI Baud Rate High value
BDL:	equ $1C		; SCI Baud Rate Low value - 9600 bps
SC1:	equ $00		; SCI CR1 value
SC2:	equ $0C		; SCI CR2 value, 8,1,N
SC3:	equ $00		; SCI CR3 value

CH0SU:	equ $20		; confog for cont conv, ch0
CH1SU:	equ $21		; config for cont conv, ch1

TLO:	equ $1F		; lower trigger value
THI:	equ $E0		; upper trigger value

MODH:	equ $FF		; Modulo Hi count
MODL:	equ $FF		; Modulo Lo count
VH:	equ $00		; TPM Hi compare value
VL:	equ $00		; TPM Lo Compare Value

EOT:	equ $04		; end of text char
RDRF:	equ $20		; Rx Data Ready Flag

; ====================  PROGRAM START  ========================================

;	org RAM			; place program in RAM;
	org FLASH		; place program in FLASH

SETUP:
	sei			; mask interrupts	
	ldhx #STACK		; H:X points to top of RAM
	txs			; init SP
	ldhx #SOPT1		; H:X points to SOPT1
	lda #$02		; load A		
	sta ,X			; COP dis, BKGD pin en

	mov #$C0,PTBD		; init PTBC[7:6]
	mov #$C0,PTBDD		; PTB[7:6] output
	 
	jsr ONSCI		; setup SCI 9600,8,N,1

;**********************************************************
;
; Setup Timer/PWM Channel as Output Compare to toggle LED 1
; output toggle rate approx 250ms 
;
;**********************************************************	
	mov #MODH,TPM1MODH	; load hi modulo count
	mov #MODL,TPM1MODL	; load lo modulo count
	mov #VH,TPM1C0VH	; load hi compare value
	mov #VL,TPM1C0VL	; load lo compare value
	mov #$54,TPM1C0SC	; en CH0 int, output compare, toggle output 
	mov #$0E,TPM1SC		; sel bus clk, prescale = 64

	cli			; unmask interrupts	 
FT:
	brset 3,PTAD,FT		; loop until SW2 pressed
	jsr LED2		; toggle LED2
	jsr DELAY		; wait
	bra FT
; ===================== Sub-Routines ==========================================

DELAY:
	lda #$04		; outer loop delay count
DLY2:	ldhx #$ffff		; inner loop delay count
DLY1:	aix #-1			; decrement H:X 
	cphx #$0000		; update CCR
	bne DLY1		; inner loop
	sub #$01		; dec acc
	bne DLY2		; outer loop
	rts			; return

LED1:	ldhx #PTBD		; PTC addr
	lda ,X			; read PTC
	eor #$40		; neg PTB[6]
	sta PTBD		; write PTB
	rts			; return
		
LED2:	ldhx #PTBD		; PTC addr
	lda ,X			; read PTC
	eor #$80		; neg PTB[7]
	sta PTBD		; write PTB
	rts			; return
ISR1:
	lda TPM1C0SC		; get CH0 status
	bclr 7,TPM1C0SC		; clr CH0 interrupt flag
	jsr LED1		; toggle LED1
	ldhx #AXM		; get text output
	jsr OUTSTRG		; send it out
	ldhx #BD		; get text
	jsr OUTSTRG		; send it out
	rti			; return

; ===================== Include Files =========================================

	include '9S08SCI.inc'	; 9S08 SCI routines
;	include 'EL32Menu.asm'	; menu sub-routines
	
; ===================== Constants =============================================

AXM:	FCB "Axiom Manufacturing"
	FCB EOT
	
BD:	FCB "DEMO9S08SH8"
	FCB EOT

; ======================== VECTORS ============================================
	org $FFF4
	DC.W ISR1	; TPM ISR
	
	org $FFFE
	DC.W SETUP	; Program Start
